# sceleto

**sceleto** is a wrapper package developed by [SCMGL](https://sites.google.com/view/scmglkaist/home?authuser=0) to aid in single cell analysis.

## Installation
You can install this package using:

```
pip install sceleto
```

Progress:
Working on compatibility issues